<?php
/**
 * AlienScience Theme core functions and definitions
 *
 * @package WordPress
 * @subpackage AlienScience
 */

/**
 * Set the content width based on the theme design and stylesheet.
 */
if ( ! isset( $content_width ) )
	$content_width = 640; /* px */

/**
 * Sets up theme defaults and registers support for various WordPress features.
 */
if ( ! function_exists( 'alienscience_setup' ) ):
function alienscience_setup() {
	
	/**
	 * Add support for post thumbnails
	 */
	add_theme_support( 'post-thumbnails' ); 
	
	/**
	 * Load textdomain
	 */
	load_theme_textdomain( 'alienscience', get_template_directory_uri() . '/languages' );
		
	/**
	 * Add default posts and comments RSS feed links to head
	 */
	add_editor_style();	

	/**
	 * Add default posts and comments RSS feed links to head
	 */
	add_theme_support( 'automatic-feed-links' );

	/**
	 * Set up configurable navigation menus
	 */
	register_nav_menus(array(
		'primary' => __( 'Main Menu', 'alienscience' ),
	));

	/**
	 * Add support for the Aside and Gallery Post Formats
	 */
	add_theme_support( 'post-formats', array( 'aside', 'image', 'gallery' ) );
	
	/**
	 * Add support for Title tags
	 */
	add_theme_support( 'title-tag' );

	add_theme_support( 'custom-logo', array( 'width' => 240, 'height' => 60 ) );
	
	add_image_size( 'alienscience_slide', 300, 200 );
}
endif; // alienscience_setup

/**
 * Tell WordPress to run alienscience_setup() when the 'after_setup_theme' hook is run.
 */
add_action( 'after_setup_theme', 'alienscience_setup' );


/**
 * Enqueue scripts
 */
add_action( 'wp_enqueue_scripts', 'alienscience_scripts' );
if ( ! function_exists( 'alienscience_scripts' ) ):
function alienscience_scripts() {

	// Queue CSS for fonts
	wp_enqueue_style( 'googlefonts', 'http://fonts.googleapis.com/css?family=Electrolize|Orbitron', false );
	wp_enqueue_style( 'fontawesome', get_template_directory_uri() . '/css/font-awesome.min.css', false, '1.0' );
	
	// Register scripts and set dependencies
	wp_register_script( 'easing', get_template_directory_uri() . '/js/jquery.easing.js', 'jquery' );
	wp_register_script( 'slider', get_template_directory_uri() . '/js/jquery.slider.min.js', 'jquery', 'easing' );
	wp_register_script( 'animatebackground', get_template_directory_uri() . '/js/jquery.animatebackground.js', 'jquery' );
	wp_register_script( 'alienscience', get_template_directory_uri() . '/as.js', 'jquery', 'slider', 'animatebackground' );
	
	// Queue scripts for dynamic linking
	wp_enqueue_script( 'jquery' );
	wp_enqueue_script( 'easing' );
	wp_enqueue_script( 'slider' );
	wp_enqueue_script( 'animatebackground' );
	wp_enqueue_script( 'alienscience' );
	
	// Add support and z-index fixing for flash embeds
	wp_enqueue_script( 'swfobject' );
	
}
endif;

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 */
function alienscience_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'alienscience_page_menu_args' );

/**
 * Register widgetized area and update sidebar with default widgets
 */
function alienscience_widgets_init() {
	register_sidebar( array(
		'name' => __( 'Sidebar', 'alienscience' ),
		'id' => 'main-sidebar',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h2 class="widget-title">',
		'after_title' => '</h2>',
	) );

	register_sidebar( array(
		'name' => __( 'Footer', 'alienscience' ),
		'id' => 'footer-sidebar',
		'description' => __( 'Max. 3 widgets.', 'alienscience' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
}
add_action( 'widgets_init', 'alienscience_widgets_init' );


/**
 * Display navigation to next/previous pages when applicable
 */
if ( ! function_exists( 'alienscience_content_nav' ) ):
function alienscience_content_nav( $nav_id ) {
	global $wp_query;

	?>
	<nav id="<?php echo $nav_id; ?>">
		<p class="assistive-text section-heading"><?php _e( 'Post navigation', 'alienscience' ); ?></p>

	<?php
		// Navigation links for single posts
		if ( is_single() ) :
		
			previous_post_link( '<div class="nav-previous">%link</div>', '<span class="meta-nav">' . _x( '&laquo;', 'Previous post', 'alienscience' ) . '</span> %title', true );
		
			next_post_link( '<div class="nav-next">%link</div>', '%title <span class="meta-nav">' . _x( '&raquo;', 'Next post', 'alienscience' ) . '</span>', true );
		
		// Navigation links for home, archive, and search pages
		elseif ( $wp_query->max_num_pages > 1 && ( is_home() || is_archive() || is_search() ) ) : ?>
        
		<?php if ( get_next_posts_link() ) : ?>
		<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&laquo;</span> Older posts', 'alienscience' ) ); ?></div>
		<?php endif; ?>

		<?php if ( get_previous_posts_link() ) : ?>
		<div class="nav-next"><?php previous_posts_link( __( 'Newer posts<span class="meta-nav">&raquo;</span>', 'alienscience' ) ); ?></div>
		<?php endif; ?>

	<?php endif; ?>

	</nav><!-- #<?php echo $nav_id; ?> -->
	<?php
}
endif; // alienscience_content_nav


/**
 * Print HTML with meta information for the current post-date/time and author.
 */
if ( ! function_exists( 'alienscience_posted_on' ) ) :
function alienscience_posted_on() {
	printf( __( '<span class="sep">Posted on </span><a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s" pubdate>%4$s</time></a><span class="byline"> <span class="sep"> by </span> <span class="author vcard"><a class="url fn n" href="%5$s" title="%6$s" rel="author">%7$s</a></span></span>', 'alienscience' ),
		esc_url( get_permalink() ),
		esc_attr( get_the_time() ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		esc_attr( sprintf( __( 'View all posts by %s', 'alienscience' ), get_the_author() ) ),
		esc_html( get_the_author() )
	);
}
endif;


/**
 * Add custom classes to the array of body classes.
 */
function alienscience_body_classes( $classes ) {
	// Adds a class of single-author to blogs with only 1 published author
	if ( ! is_multi_author() ) {
		$classes[] = 'single-author';
	}

	return $classes;
}
add_filter( 'body_class', 'alienscience_body_classes' );

/**
 * Return true if a blog has more than 1 category
 */
function alienscience_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'all_the_cool_cats' ) ) ) {
		// Create an array of all the categories that are attached to posts
		$all_the_cool_cats = get_categories( array(
			'hide_empty' => 1,
		) );

		// Count the number of categories that are attached to the posts
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'all_the_cool_cats', $all_the_cool_cats );
	}

	if ( '1' != $all_the_cool_cats ) {
		// This blog has more than 1 category so alienscience_categorized_blog should return true
		return true;
	} else {
		// This blog has only 1 category so alienscience_categorized_blog should return false
		return false;
	}
}

/**
 * Flush out the transients used in alienscience_categorized_blog
 */
function alienscience_category_transient_flusher() {
	delete_transient( 'all_the_cool_cats' );
}
add_action( 'edit_category', 'alienscience_category_transient_flusher' );
add_action( 'save_post', 'alienscience_category_transient_flusher' );


/**
 * Custom logo
 */
function alienscience_custom_logo() {
    $output = '';
    if (function_exists('get_custom_logo'))
        $output = get_custom_logo();
		
    if (empty($output))
        $output = '<h1><a href="' . esc_url( home_url('/') ) . '">' . get_bloginfo('name') . '</a></h1><div id="site-description">' . get_bloginfo('description') . '</div>';

    echo $output;
}


/**
 * Admin notices
 */


function alienscience_update_notice() {
    if ( !get_theme_mod( 'alienscience_credit_link' ) ) {
        return;
    }
    ?>
    <div class="notice updated">
        <p><?php _e( 'Thank you for using AlienScience theme. Please support this free theme by', 'alienscience' ); ?> <a href="<?php echo esc_url( __( 'http://alienscience.co.uk/upgrade', 'alienscience' ) ); ?>" target="_blank"><?php _e( 'upgrading.', 'alienscience' ) ?></a></p>
    </div>
    <?php
}
add_action( 'admin_notices', 'alienscience_update_notice' );


/**
 * Custom settings
 */
function alienscience_custom_settings( $wp_customize ) {
	
	// Custom section
	$wp_customize->add_section( 'alienscience_footer' , array(
   		'title'      => __( 'Footer', 'alienscience' ),
   		'priority'   => 117,
	) );
	
	// Credit link
	$wp_customize->add_setting( 'alienscience_credit_link' , array(
    	'default'	=> 0,
		'sanitize_callback'	=> 'esc_attr',
	) );
	$wp_customize->add_control( 
    	new WP_Customize_Control(
        	$wp_customize,
        	'alienscience_credit_link',
        	array(
            	'label'     => __('Hide Credit', 'alienscience'),
            	'section'   => 'alienscience_footer',
            	'settings'  => 'alienscience_credit_link',
           		'type'      => 'checkbox',
			)
		)
	);
	
	// Copyright text
	$wp_customize->add_setting( 'alienscience_copyright_text' , array(
    	'default'     		=> 'Published under the creative commons licence 4.0.',
		'sanitize_callback'	=> 'esc_attr',
	) );
	$wp_customize->add_control( 
    	new WP_Customize_Control(
        	$wp_customize,
        	'alienscience_copyright_text',
        	array(
            	'label'     => __('Copyright Text', 'alienscience'),
            	'section'   => 'alienscience_footer',
            	'settings'  => 'alienscience_copyright_text',
           		'type'      => 'text',
			)
		)
	);
	
	// Footer logo
	$wp_customize->add_setting( 'alienscience_footer_logo', array(
		'sanitize_callback' => 'esc_url_raw',
	) );
	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'alienscience_footer_logo',
			array(
   				'label'    => __( 'Footer Logo', 'alienscience' ),
    			'section'  => 'alienscience_footer',
    			'settings' => 'alienscience_footer_logo',
			)
		)
	);
	
}
add_action( 'customize_register', 'alienscience_custom_settings' );

/**
 * Setup the WordPress core custom background feature.
 *
 * Use add_theme_support to register support for WordPress 3.4+
 * as well as provide backward compatibility for previous versions.
 * Use feature detection of wp_get_theme() which was introduced
 * in WordPress 3.4.
 *
 * Hooks into the after_setup_theme action.
 *
 */
function alienscience_custom_background() {
    $args = array(
        'default-color' => '000000',
    );
    if ( function_exists( 'wp_get_theme' ) ) {
        add_theme_support( 'custom-background', $args );
    }
}
add_action( 'after_setup_theme', 'alienscience_custom_background' );


/**
 * This theme was built by Higher Coding with PHP, HTML5, jQuery, CSS and Alien Science.
 */
